==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/AclRuleFluent.java <==
package io.strimzi.api.kafka.model;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Object;
import java.util.Map;

public interface AclRuleFluent<A extends AclRuleFluent<A>> extends Fluent<A>{


    public AclRuleType getType();
    public A withType(AclRuleType type);
    public Boolean hasType();
    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public AclRuleResource getResource();
    public AclRuleResource buildResource();
    public A withResource(AclRuleResource resource);
    public Boolean hasResource();
    public A withAclRuleGroupResource(AclRuleGroupResource aclRuleGroupResource);
    public AclRuleFluent.AclRuleGroupResourceNested<A> withNewAclRuleGroupResource();
    public AclRuleFluent.AclRuleGroupResourceNested<A> withNewAclRuleGroupResourceLike(AclRuleGroupResource item);
    public A withAclRuleTopicResource(AclRuleTopicResource aclRuleTopicResource);
    public AclRuleFluent.AclRuleTopicResourceNested<A> withNewAclRuleTopicResource();
    public AclRuleFluent.AclRuleTopicResourceNested<A> withNewAclRuleTopicResourceLike(AclRuleTopicResource item);
    public A withAclRuleTransactionalIdResource(AclRuleTransactionalIdResource aclRuleTransactionalIdResource);
    public AclRuleFluent.AclRuleTransactionalIdResourceNested<A> withNewAclRuleTransactionalIdResource();
    public AclRuleFluent.AclRuleTransactionalIdResourceNested<A> withNewAclRuleTransactionalIdResourceLike(AclRuleTransactionalIdResource item);
    public A withAclRuleClusterResource(AclRuleClusterResource aclRuleClusterResource);
    public AclRuleFluent.AclRuleClusterResourceNested<A> withNewAclRuleClusterResource();
    public AclRuleFluent.AclRuleClusterResourceNested<A> withNewAclRuleClusterResourceLike(AclRuleClusterResource item);
    public String getHost();
    public A withHost(String host);
    public Boolean hasHost();
    public A withNewHost(String arg1);
    public A withNewHost(StringBuilder arg1);
    public A withNewHost(StringBuffer arg1);
    public AclOperation getOperation();
    public A withOperation(AclOperation operation);
    public Boolean hasOperation();

    public interface AclRuleGroupResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AclRuleGroupResourceFluent<AclRuleFluent.AclRuleGroupResourceNested<N>>{

        
    public N and();    public N endAclRuleGroupResource();
}
    public interface AclRuleTopicResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AclRuleTopicResourceFluent<AclRuleFluent.AclRuleTopicResourceNested<N>>{

        
    public N and();    public N endAclRuleTopicResource();
}
    public interface AclRuleTransactionalIdResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AclRuleTransactionalIdResourceFluent<AclRuleFluent.AclRuleTransactionalIdResourceNested<N>>{

        
    public N and();    public N endAclRuleTransactionalIdResource();
}
    public interface AclRuleClusterResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AclRuleClusterResourceFluent<AclRuleFluent.AclRuleClusterResourceNested<N>>{

        
    public N and();    public N endAclRuleClusterResource();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/AclRuleFluent.java <==
package io.strimzi.api.kafka.model;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.lang.Object;
import java.util.Map;

public interface AclRuleFluent<A extends AclRuleFluent<A>> extends Fluent<A> {


    public AclRuleType getType();
    public A withType(AclRuleType type);
    public Boolean hasType();
    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public AclRuleResource getResource();
    public AclRuleResource buildResource();
    public A withResource(AclRuleResource resource);
    public Boolean hasResource();
    public A withAclRuleGroupResource(AclRuleGroupResource aclRuleGroupResource);
    public AclRuleFluent.AclRuleGroupResourceNested<A> withNewAclRuleGroupResource();
    public AclRuleFluent.AclRuleGroupResourceNested<A> withNewAclRuleGroupResourceLike(AclRuleGroupResource item);
    public A withAclRuleTopicResource(AclRuleTopicResource aclRuleTopicResource);
    public AclRuleFluent.AclRuleTopicResourceNested<A> withNewAclRuleTopicResource();
    public AclRuleFluent.AclRuleTopicResourceNested<A> withNewAclRuleTopicResourceLike(AclRuleTopicResource item);
    public A withAclRuleTransactionalIdResource(AclRuleTransactionalIdResource aclRuleTransactionalIdResource);
    public AclRuleFluent.AclRuleTransactionalIdResourceNested<A> withNewAclRuleTransactionalIdResource();
    public AclRuleFluent.AclRuleTransactionalIdResourceNested<A> withNewAclRuleTransactionalIdResourceLike(AclRuleTransactionalIdResource item);
    public A withAclRuleClusterResource(AclRuleClusterResource aclRuleClusterResource);
    public AclRuleFluent.AclRuleClusterResourceNested<A> withNewAclRuleClusterResource();
    public AclRuleFluent.AclRuleClusterResourceNested<A> withNewAclRuleClusterResourceLike(AclRuleClusterResource item);
    public String getHost();
    public A withHost(String host);
    public Boolean hasHost();
    public A withNewHost(StringBuilder arg1);
    public A withNewHost(int[] arg1,int arg2,int arg3);
    public A withNewHost(char[] arg1);
    public A withNewHost(StringBuffer arg1);
    public A withNewHost(byte[] arg1,int arg2);
    public A withNewHost(byte[] arg1);
    public A withNewHost(char[] arg1,int arg2,int arg3);
    public A withNewHost(byte[] arg1,int arg2,int arg3);
    public A withNewHost(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewHost(String arg1);
    public AclOperation getOperation();
    public A withOperation(AclOperation operation);
    public Boolean hasOperation();
    public interface AclRuleGroupResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AclRuleGroupResourceFluent<AclRuleFluent.AclRuleGroupResourceNested<N>> {

            public N and();
            public N endAclRuleGroupResource();    }


    public interface AclRuleTopicResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AclRuleTopicResourceFluent<AclRuleFluent.AclRuleTopicResourceNested<N>> {

            public N and();
            public N endAclRuleTopicResource();    }


    public interface AclRuleTransactionalIdResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AclRuleTransactionalIdResourceFluent<AclRuleFluent.AclRuleTransactionalIdResourceNested<N>> {

            public N and();
            public N endAclRuleTransactionalIdResource();    }


    public interface AclRuleClusterResourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,AclRuleClusterResourceFluent<AclRuleFluent.AclRuleClusterResourceNested<N>> {

            public N and();
            public N endAclRuleClusterResource();    }


}
